@@ -4,15 +4,15 @@ check for supported symbols
 '''
 
 import time
-from datetime import datetime
 
 import pandas as pd
+import requests
 from python_graphql_client import GraphqlClient
 
 
 class USwapper:
     def __init__(self):
-        self.client = GraphqlClient( 'https://api.thegraph.com/subgraphs/name/ianlapham/uniswapv2' )
+        self.client = GraphqlClient( 'https://api.thegraph.com/subgraphs/name/uniswap/uniswap-v2' )
 
         while True:
             try:
@@ -50,7 +50,7 @@ class USwapper:
 
                 except ConnectionError:
                     print( 'Connection error' )
-                    time.sleep( 1 )
+                    time.sleep( 5 )
 
                 else:
                     return price
@@ -63,30 +63,18 @@ class USwapper:
         addv = ass[ass['symbol'] == symbol].index.values
         return addv[0]
 
-    def getlastupdated(self):
-        ts = int( self.client.execute( f'{{transactions(first: 1, orderBy: timestamp, orderDirection: desc ){{'
-                                       f'timestamp}}}}' )['data']['transactions'][0]['timestamp'] )
-        value = datetime.fromtimestamp( ts )
-
-        return f'{value:%Y-%m-%d %H:%M:%S}'
-
-    def getassets(self):
-        i = 0
-        ass = pd.DataFrame()
+    @staticmethod
+    def getassets():
         while True:
-            i += 1
             try:
-                res = self.client.execute( f'{{tokens(first: 1000, skip:{(i-1)*1000}){{'
-                                           f'id symbol name decimals}}}}' )['data']['tokens']
-                if len(res) == 0:
-                    break
-
+                response = requests.get( 'https://api.uniswap.info/v2/assets' )
+                response.raise_for_status()
             except ConnectionError:
-
                 print( 'Connection Error..' )
-                time.sleep( 1 )
+                time.sleep( 10 )
             else:
-                ass = ass.append(res)
+                ass = pd.DataFrame( response.json() ).T
+                ass.set_index( 'id', inplace=True )
+                ass.drop( columns=['maker_fee', 'taker_fee'], inplace=True )
+                return ass
 
-        ass.set_index('id', inplace=True)
-        return ass
